<?php exit(); ?>

<!--             2013-12-30 21:53:01             -->

<!--  **    SAVE THIS FILE AS hoteld_doc_backup.php     **  -->

<!--  **  SALVA QUESTO FILE COME hoteld_doc_backup.php  **  -->


<backup>
<versione>2.03</versione>
<database>
<tabella>
<nometabella>contratti</nometabella>
<colonnetabella>
<nomecolonna>numero</nomecolonna>
<tipocolonna>3</tipocolonna>
<nomecolonna>tipo</nomecolonna>
<tipocolonna>253</tipocolonna>
<nomecolonna>testo</nomecolonna>
<tipocolonna>252</tipocolonna>
</colonnetabella>
<righetabella>
<riga><cmp>1</cmp><cmp>vett2</cmp><cmp>iva_porc_vect_fact;num_iva_fact</cmp></riga>
<riga><cmp>2</cmp><cmp>vett2</cmp><cmp>iva_porc_exist_fact;var_tmp_fact</cmp></riga>
<riga><cmp>305</cmp><cmp>var6</cmp><cmp>apellido_ec</cmp></riga>
<riga><cmp>306</cmp><cmp>var6</cmp><cmp>apel_no_esp_ec</cmp></riga>
<riga><cmp>102</cmp><cmp>var5</cmp><cmp>apellido_eml_disp</cmp></riga>
<riga><cmp>68</cmp><cmp>var4</cmp><cmp>linea_ciudad_recibo</cmp></riga>
<riga><cmp>69</cmp><cmp>var4</cmp><cmp>linea_nacion_recibo</cmp></riga>
<riga><cmp>73</cmp><cmp>var4</cmp><cmp>cod_fisc_estruc_recibo</cmp></riga>
<riga><cmp>74</cmp><cmp>var4</cmp><cmp>nombre_recibo</cmp></riga>
<riga><cmp>75</cmp><cmp>var4</cmp><cmp>apellido_recibo</cmp></riga>
<riga><cmp>76</cmp><cmp>var4</cmp><cmp>telefono_estruc_recibo</cmp></riga>
<riga><cmp>98</cmp><cmp>var4</cmp><cmp>numero_calle_recibo</cmp></riga>
<riga><cmp>421</cmp><cmp>var4</cmp><cmp>mostrar_metodo_recibo</cmp></riga>
<riga><cmp>325</cmp><cmp>var2</cmp><cmp>linea_ciudad_fact</cmp></riga>
<riga><cmp>326</cmp><cmp>var2</cmp><cmp>linea_nacion_fact</cmp></riga>
<riga><cmp>330</cmp><cmp>var2</cmp><cmp>cod_fisc_estruc_fact</cmp></riga>
<riga><cmp>331</cmp><cmp>var2</cmp><cmp>nombre_fact</cmp></riga>
<riga><cmp>332</cmp><cmp>var2</cmp><cmp>apellido_fact</cmp></riga>
<riga><cmp>333</cmp><cmp>var2</cmp><cmp>telefono_estruc_fact</cmp></riga>
<riga><cmp>336</cmp><cmp>var2</cmp><cmp>var_tmp_fact</cmp></riga>
<riga><cmp>337</cmp><cmp>var2</cmp><cmp>tarifa_no_iva_fact</cmp></riga>
<riga><cmp>339</cmp><cmp>var2</cmp><cmp>ultima_reserva_fact</cmp></riga>
<riga><cmp>342</cmp><cmp>var2</cmp><cmp>nombre_coste_agn_fact</cmp></riga>
<riga><cmp>343</cmp><cmp>var2</cmp><cmp>tot_no_iva_fact</cmp></riga>
<riga><cmp>347</cmp><cmp>var2</cmp><cmp>coste_tot_fact</cmp></riga>
<riga><cmp>348</cmp><cmp>var2</cmp><cmp>coste_tot_fact_p</cmp></riga>
<riga><cmp>349</cmp><cmp>var2</cmp><cmp>iva_fact_p</cmp></riga>
<riga><cmp>350</cmp><cmp>var2</cmp><cmp>tot_no_iva_fact_p</cmp></riga>
<riga><cmp>351</cmp><cmp>var2</cmp><cmp>coste_agn_no_iva_fact_p</cmp></riga>
<riga><cmp>352</cmp><cmp>var2</cmp><cmp>descuento_no_iva_fact_p</cmp></riga>
<riga><cmp>353</cmp><cmp>var2</cmp><cmp>tarifa_no_iva_fact_p</cmp></riga>
<riga><cmp>355</cmp><cmp>var2</cmp><cmp>numero_calle_fact</cmp></riga>
<riga><cmp>405</cmp><cmp>var2</cmp><cmp>codigo_fiscal_fact</cmp></riga>
<riga><cmp>406</cmp><cmp>var2</cmp><cmp>num_identificacion_fiscal_fact</cmp></riga>
<riga><cmp>407</cmp><cmp>var2</cmp><cmp>calle_fact</cmp></riga>
<riga><cmp>408</cmp><cmp>var2</cmp><cmp>num_iva_fact</cmp></riga>
<riga><cmp>409</cmp><cmp>var2</cmp><cmp>ens_tarifa_fact</cmp></riga>
<riga><cmp>410</cmp><cmp>var2</cmp><cmp>ens_descuento_fact</cmp></riga>
<riga><cmp>411</cmp><cmp>var2</cmp><cmp>ens_coste_agn_fact</cmp></riga>
<riga><cmp>412</cmp><cmp>var2</cmp><cmp>num_ripeticion_fact</cmp></riga>
<riga><cmp>413</cmp><cmp>var2</cmp><cmp>tot_parc_no_iva_fact</cmp></riga>
<riga><cmp>414</cmp><cmp>var2</cmp><cmp>tot_parc_iva_fact</cmp></riga>
<riga><cmp>415</cmp><cmp>var2</cmp><cmp>tot_parc_no_iva_fact_p</cmp></riga>
<riga><cmp>416</cmp><cmp>var2</cmp><cmp>tot_parc_iva_fact_p</cmp></riga>
<riga><cmp>417</cmp><cmp>var2</cmp><cmp>max_num_iva_fact</cmp></riga>
<riga><cmp>418</cmp><cmp>var2</cmp><cmp>frase_personas_fact</cmp></riga>
<riga><cmp>419</cmp><cmp>var2</cmp><cmp>une_descuento_a_tarifa</cmp></riga>
<riga><cmp>420</cmp><cmp>var2</cmp><cmp>logo_fact</cmp></riga>
<riga><cmp>422</cmp><cmp>var2</cmp><cmp>nombre_coste_tasa_fact</cmp></riga>
<riga><cmp>423</cmp><cmp>var2</cmp><cmp>ens_coste_tasa_fact</cmp></riga>
<riga><cmp>424</cmp><cmp>var2</cmp><cmp>iva_fact</cmp></riga>
<riga><cmp>425</cmp><cmp>var2</cmp><cmp>tot_costes_tasa_fact</cmp></riga>
<riga><cmp>426</cmp><cmp>var2</cmp><cmp>ens_coste_como_tasas_fact</cmp></riga>
<riga><cmp>427</cmp><cmp>var2</cmp><cmp>ens_subtotal_fact</cmp></riga>
<riga><cmp>1</cmp><cmp>var</cmp><cmp>Mr</cmp></riga>
<riga><cmp>3</cmp><cmp>var</cmp><cmp>il</cmp></riga>
<riga><cmp>4</cmp><cmp>var</cmp><cmp>Il_</cmp></riga>
<riga><cmp>5</cmp><cmp>var</cmp><cmp>al</cmp></riga>
<riga><cmp>6</cmp><cmp>var</cmp><cmp>e</cmp></riga>
<riga><cmp>7</cmp><cmp>var</cmp><cmp>o</cmp></riga>
<riga><cmp>13</cmp><cmp>var</cmp><cmp>el</cmp></riga>
<riga><cmp>14</cmp><cmp>var</cmp><cmp>El_</cmp></riga>
<riga><cmp>15</cmp><cmp>var</cmp><cmp>al3</cmp></riga>
<riga><cmp>16</cmp><cmp>var</cmp><cmp>a</cmp></riga>
<riga><cmp>17</cmp><cmp>var</cmp><cmp>o3</cmp></riga>
<riga><cmp>5</cmp><cmp>opzeml</cmp><cmp>;;</cmp></riga>
<riga><cmp>6</cmp><cmp>opzeml</cmp><cmp>;SI;</cmp></riga>
<riga><cmp>5</cmp><cmp>oggetto</cmp><cmp>Disponibilidad</cmp></riga>
<riga><cmp>6</cmp><cmp>oggetto</cmp><cmp>Confirmación reserva</cmp></riga>
<riga><cmp>1</cmp><cmp>nomi_con</cmp><cmp>1#?&Ejemplo#@&2#?&Factura#@&3#?&Factura - html#@&4#?&Recibo último pago#@&5#?&Email disponibilidad#@&6#?&Email confirmación</cmp></riga>
<riga><cmp>3</cmp><cmp>nomefile</cmp><cmp>Factura</cmp></riga>
<riga><cmp>5</cmp><cmp>mln_es</cmp><cmp>Estimad[o] Señor[a] [apellido_eml_disp],
le confirmo la disponibilidad de un apartamento[c num_personas_tot!=""] para [num_personas_tot] personas[/c] para el período desde el [fecha_inicial] hasta el [fecha_final]. El precio para dicho período es de [coste_tot_p] [nombre_divisa] (incluyendo costes asociados).

En el caso de que desee reservar le ruego me envie su confirmación respondiendo a este correo electrónico.

Estaré a su disposición para cualquier otra información que necesite.

Saludos,
[nombre_contacto_estructura]

[nombre_estructura]
[sitio_web_estructura]


[texto_citado_email_pedido]
</cmp></riga>
<riga><cmp>6</cmp><cmp>mln_es</cmp><cmp>Estimad[o] Señor[a] [apellido_ec],
le confirmo que he reservado a su nombre un apartamento[c num_personas_tot!=""] para [num_personas_tot] personas[/c] para el período desde el [fecha_inicial] hasta el [fecha_final]. El precio para dicho período es de [coste_tot_p] [nombre_divisa] (incluyendo costes asociados). Para completar la reserva es necesario pagar por adelantado [fianza_p] [nombre_divisa], puede efectuar este pago siguiendo este enlace:

http://recorrido-modelo-confirma-reserva/mdl_confirma_reserva.php?cognome=[apel_no_esp_ec]&cod_prenota=[codice_prenotazione]

Si el enlace no funcionara correctamente puede intentar utilizar este otro:

http://recorrido-modelo-confirma-reserva/mdl_confirma_reserva.php

e insertar después:

Apellido: [apellido]
Código reserva: [codigo_reserva]

Estaré a su disposición para cualquier otra información que necesite.

Saludos,
[nombre_contacto_estructura]

[nombre_estructura]
[sitio_web_estructura]
</cmp></riga>
<riga><cmp>5</cmp><cmp>mln_en</cmp><cmp>Dear Mr[Mr] [apellido_eml_disp],
I confirm you the availability of an apartment[c people_num_tot!=""] for [people_num_tot] people[/c] in the period from [starting_date] to [ending_date]. The price for this period is [price_tot_p] [currency_name] (including cleaning and utilities).

If you are interested in reserving the apartment you can contact me by replaying to this email.

Please let me know if you have any question.

Best regards,
[structure_contact_name]

[structure_name]
[structure_website]


[enquiry_email_quoted_text]
</cmp></riga>
<riga><cmp>6</cmp><cmp>mln_en</cmp><cmp>Dear Mr[Mr] [apellido_ec],
I confirm you that I have reserved you an apartment[c people_num_tot!=""] for [people_num_tot] people[/c] in the period from [starting_date] to [ending_date]. The price for this period is [price_tot_p] [currency_name] (including cleaning and utilities). In order to complete the reservation you must send a down-payment of [deposit_p] [currency_name], you can pay it following this link:

http://path-confirm-reservation-template/confirm_reservation_tpl.php?cognome=[apel_no_esp_ec]&cod_prenota=[codice_prenotazione]

If the above link does not work properly for you, try this other one:

http://path-confirm-reservation-template/confirm_reservation_tpl.php

and then insert:

Surname: [surname]
Reservation code: [reservation_code]

Please let me know if you have any other question.

Best regards,
[structure_contact_name]

[structure_name]
[structure_website]
</cmp></riga>
<riga><cmp>3</cmp><cmp>impor_vc</cmp><cmp>2</cmp></riga>
<riga><cmp>2</cmp><cmp>dir</cmp><cmp>~</cmp></riga>
<riga><cmp>3</cmp><cmp>dir</cmp><cmp>~</cmp></riga>
<riga><cmp>2</cmp><cmp>contrrtf</cmp><cmp>{\rtf1\ansi\deff1\adeflang1025[r][r3][/r3] [/r]
{\fonttbl{\f0\froman\fprq2\fcharset0 Times New Roman;}{\f1\froman\fprq2\fcharset0 Times New Roman;}{\f2\fswiss\fprq2\fcharset0 Arial;}{\f3\fswiss\fprq2\fcharset0 Arial;}{\f4\fswiss\fprq2\fcharset0 Bitstream Vera Sans;}{\f5\fswiss\fprq2\fcharset0 Tahoma;}{\f6\froman\fprq2\fcharset0 Garamond;}{\f7\froman\fprq2\fcharset0 Times New Roman;}{\f8\fnil\fprq2\fcharset0 Bitstream Vera Sans;}}
{\colortbl;\red0\green0\blue0;\red230\green230\blue230;\red255\green255\blue255;\red204\green204\blue204;\red128\green128\blue128;}
{\stylesheet{\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\snext1 Normal;}
{\s2\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af8\afs28\lang255\ltrch\dbch\af8\langfe255\hich\f2\fs28\lang1040\loch\f2\fs28\lang1040\sbasedon1\snext3 Heading;}
{\s3\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af3\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon1\snext3 Body Text;}
{\s4{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon3\snext4 List;}
{\s5\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext5 caption;}
{\s6{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext6 Index;}
{\s7\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 Heading;}
{\s8\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext8 caption;}
{\s9{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext9 Index;}
{\s10\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading;}
{\s11\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext11 WW-caption;}
{\s12{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext12 WW-Index;}
{\s13\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading1;}
{\s14\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext14 WW-caption1;}
{\s15{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext15 WW-Index1;}
{\s16\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading11;}
{\s17\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext17 WW-caption11;}
{\s18{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext18 WW-Index11;}
{\s19\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading111;}
{\s20\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext20 WW-caption111;}
{\s21{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext21 WW-Index111;}
{\s22\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading1111;}
{\s23\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext23 WW-caption1111;}
{\s24{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext24 WW-Index1111;}
{\s25\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading11111;}
{\s26\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext26 WW-caption11111;}
{\s27{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext27 WW-Index11111;}
{\s28\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading111111;}
{\s29\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext29 WW-caption111111;}
{\s30{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext30 WW-Index111111;}
{\s31\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading1111111;}
{\s32\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext32 WW-caption1111111;}
{\s33{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext33 WW-Index1111111;}
{\s34\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af4\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f4\fs28\lang1040\loch\f4\fs28\lang1040\sbasedon1\snext3 WW-Heading11111111;}
{\s35\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext35 WW-caption11111111;}
{\s36{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af3\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon1\snext36 WW-Index11111111;}
{\s37\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs20\lang255\ai\ltrch\dbch\af3\langfe255\hich\f1\fs20\lang1033\i\loch\f1\fs20\lang1033\i\sbasedon1\snext37 Dicitura;}
{\s38{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af5\afs16\lang255\ltrch\dbch\af3\langfe255\hich\f5\fs16\lang1033\loch\f5\fs16\lang1033\sbasedon1\snext38 WW-Testo fumetto;}
{\s39{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon3\snext39 Frame contents;}
{\s40{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon3\snext40 Table Contents;}
{\s41\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ab\ltrch\dbch\langfe255\hich\f1\fs24\lang1033\i\b\loch\f1\fs24\lang1033\i\b\sbasedon40\snext41 Table Heading;}
{\s42{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext42 WW-Table Contents;}
{\s43\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon42\snext43 WW-Table Heading;}
{\s44{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext44 WW-Table Contents1;}
{\s45\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon44\snext45 WW-Table Heading1;}
{\s46{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext46 WW-Table Contents12;}
{\s47\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon46\snext47 WW-Table Heading12;}
{\s48{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext48 WW-Table Contents123;}
{\s49\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon48\snext49 WW-Table Heading123;}
{\s50{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext50 WW-Table Contents1234;}
{\s51\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon50\snext51 WW-Table Heading1234;}
{\s52{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext52 WW-Table Contents12345;}
{\s53\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon52\snext53 WW-Table Heading12345;}
{\s54{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext54 WW-Table Contents123456;}
{\s55\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon54\snext55 WW-Table Heading123456;}
{\s56{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext56 WW-Table Contents1234567;}
{\s57\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon56\snext57 WW-Table Heading1234567;}
{\s58{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext58 WW-Table Contents12345678;}
{\s59\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon58\snext59 WW-Table Heading12345678;}
{\s60{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext60 Table Contents;}
{\s61\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon60\snext61 Table Heading;}
{\*\cs63\cf0\rtlch\af1\afs24\lang255\ltrch\dbch\af3\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 WW-Car. predefinito paragrafo;}
}
{\info{\creatim\yr2007\mo9\dy28\hr15\min45}{\revtim\yr1601\mo1\dy1\hr0\min0}{\printim\yr1601\mo1\dy1\hr0\min0}{\comment StarWriter}{\vern3000}}\deftab708
{\*\pgdsctbl
{\pgdsc0\pgdscuse195\pgwsxn11905\pghsxn16837\marglsxn1134\margrsxn1134\margtsxn885\margbsxn1012\pgdscnxt0 Standard;}}
{\*\pgdscno0}\paperh16837\paperw11905\margl1134\margr1134\margt885\margb1012\sectd\sbknone\pgwsxn11905\pghsxn16837\marglsxn1134\margrsxn1134\margtsxn885\margbsxn1012\ftnbj\ftnstart1\ftnrstcont\ftnnar\aenddoc\aftnrstcont\aftnstart1\aftnnrlc
\pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs28\lang255\ab\ltrch\dbch\af1\langfe255\hich\f6\fs28\lang1040\b\loch\f6\fs28\lang1040\b {\rtlch \ltrch\loch\f6\fs28\lang1040\i0\b [tipo_estructura] [nombre_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [razon_social_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [direccion_estructura] - [ciudad_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [codigo_postal_estructura] [nacion_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 C.I.F. [certificado_identificacion_fiscal_estructura] [cod_fisc_estruc_fact]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [telefono_estruc_fact]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\li5370\ri0\lin5370\rin0\fi0\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 Cliente [nombre_fact] [apellido_fact] }
[c calle_fact!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [calle_fact][numero_calle_fact]}
[/c][c linea_ciudad_fact!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [linea_ciudad_fact]}
[/c][c linea_nacion_fact!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [linea_nacion_fact]}
[/c][c codigo_fiscal_fact!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab C.I.F. [codigo_fiscal_fact]}
[/c][c num_identificacion_fiscal_fact!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab D.N.I. / N.I.F. [num_identificacion_fiscal_fact]}
[/c]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\brdrb\brdrs\brdrw20\brdrcf1\brsp20{\*\brdrb\brdlncol1\brdlnin0\brdlnout20\brdlndist0}\brsp20\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1\tx3540{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 \tab }
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 Factura n. [numero_progresivo_documento] del [hoy]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \trowd\trql\trleft276\trrh-119\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrb\brdrs\brdrw1\brdrcf1\cellx7792\clbrdrb\brdrs\brdrw1\brdrcf1\clvertalb\cellx9637
[r4 array="iva_porc_vect_fact"]
\pard\intbl\pard\plain \intbl\ltrpar\s1\cf0\cbpat3\ql\rtlch\afs12\lang255\ltrch\dbch\langfe255\hich\fs12\lang1040\loch\fs12\lang1040 
\cell\pard\plain \intbl\ltrpar\s1\cf0\ql\rtlch\afs24\lang255\ltrch\dbch\langfe255\hich\fs24\lang1040\loch\fs24\lang1040 
[r]
[c ens_tarifa_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Estancia desde el [fecha_inicial] al [fecha_final][frase_personas_fact]}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tarifa_no_iva_fact_p]}
[/c][c ens_descuento_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Descuento}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [descuento_no_iva_fact_p]}
[/c]
[r3][c ens_coste_agn_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Extra: \'93[nombre_coste_agna]\'94}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [coste_agn_no_iva_fact_p]}
[/c][c ens_coste_como_tasas_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Tasa: \'93[nombre_coste_agna]\'94}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tasas_coste_agna_p]}
[/c][/r3][/r]
[c ens_subtotal_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Imponible al [iva_porc_vect_fact(num_iva_fact)]%}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tot_parc_no_iva_fact_p]}
\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Iva al [iva_porc_vect_fact(num_iva_fact)]%}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tot_parc_iva_fact_p]}
[/c]\cell\row\pard \trowd\trql\trleft276\trrh-119\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\cellx7792\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\clvertalb\cellx9637
[/r4]
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs12\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs12\lang1040\loch\f1\fs12\lang1040 
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Total Imponible}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tot_no_iva_fact_p]}
\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Total Impuestos[c num_iva_fact="1"] al [iva_porc_vect_fact(num_iva_fact)]%[/c]}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [iva_fact_p]}
[r][r3][c ens_coste_tasa_fact="1"]
\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_coste_agna]}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [coste_agn_no_iva_fact_p]}
[/c][/r3][/r]
\cell\row\pard \trowd\trql\trleft276\trrh-119\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\cellx7792\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs12\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs12\lang1040\loch\f1\fs12\lang1040 
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat4\cellx7792\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat4\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1\cf0\ql\rtlch\afs24\lang255\ltrch\dbch\langfe255\hich\fs24\lang1040\loch\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Total Factura}
\cell\pard\plain \intbl\ltrpar\s1\cf0\qr\rtlch\afs24\lang255\ab\ltrch\dbch\langfe255\hich\fs24\lang1040\b\loch\fs24\lang1040\b {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b [nombre_divisa] [coste_tot_fact_p]}
\cell\row\pard \pard\plain \ltrpar\s1\cf0\ql\rtlch\afs24\lang255\ltrch\dbch\langfe255\hich\fs24\lang1040\loch\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\brdrb\brdrs\brdrw20\brdrcf1\brsp20{\*\brdrb\brdlncol1\brdlnin0\brdlnout20\brdlndist0}\brsp20\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par }</cmp></riga>
<riga><cmp>4</cmp><cmp>contrrtf</cmp><cmp>{\rtf1\ansi\deff1\adeflang1025
{\fonttbl{\f0\froman\fprq2\fcharset0 Times New Roman;}{\f1\froman\fprq2\fcharset0 Times New Roman;}{\f2\fswiss\fprq2\fcharset0 Arial;}{\f3\fswiss\fprq2\fcharset0 Arial;}{\f4\fswiss\fprq2\fcharset0 Bitstream Vera Sans;}{\f5\fswiss\fprq2\fcharset0 Tahoma;}{\f6\froman\fprq2\fcharset0 Garamond;}{\f7\froman\fprq2\fcharset0 Times New Roman;}{\f8\fnil\fprq2\fcharset0 Bitstream Vera Sans;}}
{\colortbl;\red0\green0\blue0;\red230\green230\blue230;\red255\green255\blue255;\red204\green204\blue204;\red128\green128\blue128;}
{\stylesheet{\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\snext1 Normal;}
{\s2\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af8\afs28\lang255\ltrch\dbch\af8\langfe255\hich\f2\fs28\lang1040\loch\f2\fs28\lang1040\sbasedon1\snext3 Heading;}
{\s3\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af3\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon1\snext3 Body Text;}
{\s4{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon3\snext4 List;}
{\s5\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext5 caption;}
{\s6{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext6 Index;}
{\s7\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 Heading;}
{\s8\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext8 caption;}
{\s9{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext9 Index;}
{\s10\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading;}
{\s11\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext11 WW-caption;}
{\s12{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext12 WW-Index;}
{\s13\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading1;}
{\s14\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext14 WW-caption1;}
{\s15{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext15 WW-Index1;}
{\s16\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading11;}
{\s17\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext17 WW-caption11;}
{\s18{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext18 WW-Index11;}
{\s19\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading111;}
{\s20\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext20 WW-caption111;}
{\s21{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext21 WW-Index111;}
{\s22\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading1111;}
{\s23\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext23 WW-caption1111;}
{\s24{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext24 WW-Index1111;}
{\s25\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading11111;}
{\s26\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext26 WW-caption11111;}
{\s27{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext27 WW-Index11111;}
{\s28\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading111111;}
{\s29\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext29 WW-caption111111;}
{\s30{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext30 WW-Index111111;}
{\s31\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af3\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f3\fs28\lang1040\loch\f3\fs28\lang1040\sbasedon1\snext3 WW-Heading1111111;}
{\s32\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext32 WW-caption1111111;}
{\s33{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext33 WW-Index1111111;}
{\s34\sb240\sa120\keepn{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af4\afs28\lang255\ltrch\dbch\af4\langfe255\hich\f4\fs28\lang1040\loch\f4\fs28\lang1040\sbasedon1\snext3 WW-Heading11111111;}
{\s35\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\i\loch\f1\fs24\lang1040\i\sbasedon1\snext35 WW-caption11111111;}
{\s36{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af3\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon1\snext36 WW-Index11111111;}
{\s37\sb120\sa120{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs20\lang255\ai\ltrch\dbch\af3\langfe255\hich\f1\fs20\lang1033\i\loch\f1\fs20\lang1033\i\sbasedon1\snext37 Dicitura;}
{\s38{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af5\afs16\lang255\ltrch\dbch\af3\langfe255\hich\f5\fs16\lang1033\loch\f5\fs16\lang1033\sbasedon1\snext38 WW-Testo fumetto;}
{\s39{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon3\snext39 Frame contents;}
{\s40{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1033\loch\f1\fs24\lang1033\sbasedon3\snext40 Table Contents;}
{\s41\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ai\ab\ltrch\dbch\langfe255\hich\f1\fs24\lang1033\i\b\loch\f1\fs24\lang1033\i\b\sbasedon40\snext41 Table Heading;}
{\s42{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext42 WW-Table Contents;}
{\s43\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon42\snext43 WW-Table Heading;}
{\s44{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext44 WW-Table Contents1;}
{\s45\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon44\snext45 WW-Table Heading1;}
{\s46{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext46 WW-Table Contents12;}
{\s47\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon46\snext47 WW-Table Heading12;}
{\s48{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext48 WW-Table Contents123;}
{\s49\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon48\snext49 WW-Table Heading123;}
{\s50{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext50 WW-Table Contents1234;}
{\s51\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon50\snext51 WW-Table Heading1234;}
{\s52{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext52 WW-Table Contents12345;}
{\s53\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon52\snext53 WW-Table Heading12345;}
{\s54{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext54 WW-Table Contents123456;}
{\s55\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon54\snext55 WW-Table Heading123456;}
{\s56{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext56 WW-Table Contents1234567;}
{\s57\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon56\snext57 WW-Table Heading1234567;}
{\s58{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext58 WW-Table Contents12345678;}
{\s59\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon58\snext59 WW-Table Heading12345678;}
{\s60{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040\sbasedon1\snext60 Table Contents;}
{\s61\qc{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ab\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\b\loch\f1\fs24\lang1040\b\sbasedon60\snext61 Table Heading;}
{\*\cs63\cf0\rtlch\af1\afs24\lang255\ltrch\dbch\af3\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 WW-Car. predefinito paragrafo;}
}
{\info{\creatim\yr2007\mo9\dy28\hr15\min45}{\revtim\yr1601\mo1\dy1\hr0\min0}{\printim\yr1601\mo1\dy1\hr0\min0}{\comment StarWriter}{\vern3000}}\deftab708
{\*\pgdsctbl
{\pgdsc0\pgdscuse195\pgwsxn11905\pghsxn16837\marglsxn1134\margrsxn1134\margtsxn885\margbsxn1012\pgdscnxt0 Standard;}}
{\*\pgdscno0}\paperh16837\paperw11905\margl1134\margr1134\margt885\margb1012\sectd\sbknone\pgwsxn11905\pghsxn16837\marglsxn1134\margrsxn1134\margtsxn885\margbsxn1012\ftnbj\ftnstart1\ftnrstcont\ftnnar\aenddoc\aftnrstcont\aftnstart1\aftnnrlc
[r][c numero_ripetizione_prenotazioni!="1"]\par \page [/c]\pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs28\lang255\ab\ltrch\dbch\af1\langfe255\hich\f6\fs28\lang1040\b\loch\f6\fs28\lang1040\b {\rtlch \ltrch\loch\f6\fs28\lang1040\i0\b [tipo_estructura] [nombre_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [razon_social_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [direccion_estructura] - [ciudad_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [codigo_postal_estructura] [nacion_estructura]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 C.I.F. [certificado_identificacion_fiscal_estructura] [cod_fisc_estruc_recibo]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [telefono_estruc_recibo]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\li5370\ri0\lin5370\rin0\fi0\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 [c apellido_recibo!=""]Cliente  [nombre_recibo] [apellido_recibo][/c] }
[c via!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [via][numero_calle_recibo]}
[/c][c linea_ciudad_recibo!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [linea_ciudad_recibo]}
[/c][c linea_nacion_recibo!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab [linea_nacion_recibo]}
[/c][c certificado_identificacion_fiscal!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab C.I.F. [certificado_identificacion_fiscal]}
[/c][c num_identificacion_fiscal!=""]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 \tab \tab \tab \tab \tab \tab \tab \tab N.I.F. / D.N.I. [num_identificacion_fiscal]}
[/c]\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\brdrb\brdrs\brdrw20\brdrcf1\brsp20{\*\brdrb\brdlncol1\brdlnin0\brdlnout20\brdlndist0}\brsp20\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1\tx3540{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 \tab }
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af6\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f6\fs24\lang1040\loch\f6\fs24\lang1040 {\rtlch \ltrch\loch\f6\fs24\lang1040\i0\b0 Recibo[c numero_progresivo_documento!=""] n. [numero_progresivo_documento][/c] del [hoy]}
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \trowd\trql\trleft276\trrh-119\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrb\brdrs\brdrw1\brdrcf1\cellx7792\clbrdrb\brdrs\brdrw1\brdrcf1\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1\cf0\cbpat3\ql\rtlch\afs12\lang255\ltrch\dbch\langfe255\hich\fs12\lang1040\loch\fs12\lang1040 
\cell\pard\plain \intbl\ltrpar\s1\cf0\ql\rtlch\afs24\lang255\ltrch\dbch\langfe255\hich\fs24\lang1040\loch\fs24\lang1040 
\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [c fecha_inicial!=""]Reserva desde [fecha_inicial] hasta [fecha_final][/c][c num_personas_tot!=""] para [num_personas_tot] personas[/c][c fecha_inicial=""][metodo_ultimo_pago][/c]}
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [c mostrar_metodo_recibo="1"][nombre_divisa] [valor_ultimo_pago_p][/c]}
\cell\row\pard \trowd\trql\trleft276\trrh-119\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\cellx7792\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat3\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs12\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs12\lang1040\loch\f1\fs12\lang1040 
\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat4\cellx7792\clbrdrt\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat4\clvertalb\cellx9637
\pard\intbl\pard\plain \intbl\ltrpar\s1\cf0\ql\rtlch\afs24\lang255\ltrch\dbch\langfe255\hich\fs24\lang1040\loch\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Total Pago}
\cell\pard\plain \intbl\ltrpar\s1\cf0\qr\rtlch\afs24\lang255\ab\ltrch\dbch\langfe255\hich\fs24\lang1040\b\loch\fs24\lang1040\b {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b [nombre_divisa] [valor_ultimo_pago_p]}
\cell\row\pard \pard\plain \ltrpar\s1\cf0\ql\rtlch\afs24\lang255\ltrch\dbch\langfe255\hich\fs24\lang1040\loch\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\brdrb\brdrs\brdrw20\brdrcf1\brsp20{\*\brdrb\brdlncol1\brdlnin0\brdlnout20\brdlndist0}\brsp20\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
\par \pard\plain \ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 
[/r]\par }</cmp></riga>
<riga><cmp>1</cmp><cmp>contrhtm</cmp><cmp><B><U><FONT FACE="Times" SIZE=4><P ALIGN="CENTER">EJEMPLO DE CONTRATO PARA HOTELDRUID</P>
</U></B></FONT><FONT FACE="Times"><P ALIGN="JUSTIFY"></P>
<P ALIGN="JUSTIFY">&nbsp;</P><P ALIGN="JUSTIFY">
[El_] señor[a] [nombre] [apellido] nacid[o3] el [fecha_nacimiento] residente en [ciudad] [calle2] n 
[numero_calle] tel [telefono] alqilará un apartamento en hoteldruid
con su familia de [num_personas_tot] personas desde [fecha_inicial] hasta [fecha_final].
El precio será de [coste_tot_p]. Ha dejado una fianza de [fianza_p].
</P>
<P ALIGN="JUSTIFY">
Nign sitio, [hoy].
</P>
<P ALIGN="JUSTIFY"></P><P ALIGN="JUSTIFY">
El cliente&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
El proprietario</P>
<P ALIGN="JUSTIFY"></P>
<P ALIGN="JUSTIFY"> 
__________&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;____________</P>
<P ALIGN="JUSTIFY"></P>
</FONT></cmp></riga>
<riga><cmp>3</cmp><cmp>contrhtm</cmp><cmp><div class="cuadro_factura" style="width: 780px; margin: 10px; border: solid 1px black; padding: 30px; font-size: 12px; page-break-after: always">
[r][r3][/r3] [/r]

<div class="datos_estructura">
[logo_fact]
<div class="nombre_estructura" style="font-size: large;">[tipo_estructura] [nombre_estructura]</div>
[razon_social_estructura]<br>
[direccion_estructura] - [ciudad_estructura]<br>
[codigo_postal_estructura] [nacion_estructura]<br>
C.I.F. [certificado_identificacion_fiscal_estructura] [cod_fisc_estruc_fact]<br>
[telefono_estruc_fact]<br>
</div>

<div class="datos_cliente" style="padding: 18px 0 8px 440px;">
Cliente [nombre_fact] [apellido_fact]<br>
[c calle_fact!=""][calle_fact][numero_calle_fact]<br>
[/c][c linea_ciudad_fact!=""][linea_ciudad_fact]<br>
[/c][c linea_nacion_fact!=""][linea_nacion_fact]<br>
[/c][c codigo_fiscal_fact!=""]C.I.F. [codigo_fiscal_fact]<br>
[/c][c num_identificacion_fiscal_fact!=""]D.N.I. / N.I.F. [num_identificacion_fiscal_fact]<br>
[/c]
</div>

<hr style="width: 100%; border: 1px solid black;">

<div class="numero_factura" style="padding: 24px 0 8px 0">
Factura n. [numero_progresivo_documento] del [hoy]
</div>


[r4 array="iva_porc_vect_fact"]
<table class="lista_factura" border="1" cellpadding="5" style="border: 1px black solid; width: 740px; margin-left: auto; margin-right: 5px; margin-top: 8px; border-collapse: collapse; background-color: #e6e6e6;">
[r]
[c ens_tarifa_fact="1"]<tr><td style="border-color: black;">Estancia desde el [fecha_inicial] al [fecha_final][frase_personas_fact]</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tarifa_no_iva_fact_p]</td></tr>
[/c][c ens_descuento_fact="1"]<tr><td style="border-color: black;">Descuento</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [descuento_no_iva_fact_p]</td></tr>
[/c]
[r3][c ens_coste_agn_fact="1"]<tr><td style="border-color: black;">Extra: "[nombre_coste_agna]"</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [coste_agn_no_iva_fact_p]</td></tr>
[/c][c ens_coste_como_tasas_fact="1"]<tr><td style="border-color: black;">Tasa: "[nombre_coste_agna]"</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tasas_coste_agna_p]</td></tr>
[/c][/r3][/r]
[c ens_subtotal_fact="1"]<tr><td style="border-color: black;">Imponible al [iva_porc_vect_fact(num_iva_fact)]%</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tot_parc_no_iva_fact_p]</td></tr>
<tr><td style="border-color: black;">Iva al [iva_porc_vect_fact(num_iva_fact)]%</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tot_parc_iva_fact_p]</td></tr>
[/c]
</table>
[/r4]

<table class="imponible_factura" border="1" cellpadding="5" style="border: 1px black solid; width: 740px; margin-left: auto; margin-right: 5px; margin-top: 8px; border-collapse: collapse; background-color: #e6e6e6;">
<tr><td style="border-color: black;">Total Imponible</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tot_no_iva_fact_p]</td></tr>
<tr><td style="border-color: black;">Total Impuestos[c num_iva_fact="1"] al [iva_porc_vect_fact(num_iva_fact)]%[/c]</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [iva_fact_p]</td></tr>
[r][r3][c ens_coste_tasa_fact="1"]
<tr><td style="border-color: black;">[nombre_coste_agna]</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [coste_agn_no_iva_fact_p]</td></tr>
[/c][/r3][/r]
</table>

<table class="total_factura" border="1" cellpadding="5" style="border: 1px black solid; width: 740px; margin-left: auto; margin-right: 5px; margin-top: 8px; border-collapse: collapse; background-color: #cccccc;">
<tr><td style="border-color: black;">Total Factura</td>
<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [coste_tot_fact_p]</td></tr>
</table>


<br>
<hr style="width: 100%; border: 1px solid black;">
<br>


</div></cmp></riga>
<riga><cmp>7</cmp><cmp>contrhtm</cmp><cmp></cmp></riga>
<riga><cmp>8</cmp><cmp>contrhtm</cmp><cmp></cmp></riga>
<riga><cmp>9</cmp><cmp>contrhtm</cmp><cmp></cmp></riga>
<riga><cmp>10</cmp><cmp>contrhtm</cmp><cmp></cmp></riga>
<riga><cmp>5</cmp><cmp>contreml</cmp><cmp>#!mln!#es</cmp></riga>
<riga><cmp>6</cmp><cmp>contreml</cmp><cmp>#!mln!#es</cmp></riga>
<riga><cmp>1</cmp><cmp>cond6</cmp><cmp>rpt#@?#@?set#%?305#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>2</cmp><cmp>cond6</cmp><cmp>rpt#@?#@?set#%?306#%?=#%?var#%?cognome#%?txt#%? #%?txt#%?</cmp></riga>
<riga><cmp>1</cmp><cmp>cond5</cmp><cmp>rpt#@?#@?set#%?102#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>87</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?73#%?=#%?txt#%?- N.I.F. #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>88</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?73#%?.=#%?var#%?codice_fiscale_struttura#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>89</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?76#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>92</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?76#%?=#%?txt#%?Tel. #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>94</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?76#%?.=#%?var#%?telefono_struttura#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>97</cmp><cmp>cond4</cmp><cmp>rpt#@?and#$?telefono_struttura#%?!=#%?txt#%?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?76#%?.=#%?txt#%? - #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>98</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?76#%?.=#%?var#%?sito_web_struttura#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>99</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?74#%?=#%?var#%?nome#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>100</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?75#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>101</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?98#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>102</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?98#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>103</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?98#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>104</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?68#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>105</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?68#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>107</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?68#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>108</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?68#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>109</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?68#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>110</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?69#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>111</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?69#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>112</cmp><cmp>cond4</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?69#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>113</cmp><cmp>cond4</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?69#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>114</cmp><cmp>cond4</cmp><cmp>rpt#@?#@?set#%?421#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>115</cmp><cmp>cond4</cmp><cmp>rpt#@?and#$?data_inizio#%?=#%?txt#%?#$?metodo_ultimo_pagamento#%?!=#%?txt#%?#@?set#%?421#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>25</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?409#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>26</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?iva_porc_vect_fact(num_iva_fact)#%?=#%?var#%?percentuale_tasse_tariffa#$?num_ripeticion_fact#%?>#%?txt#%?1#@?set#%?409#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>27</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>30</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?ens_tarifa_fact#%?=#%?txt#%?1#$?sconto#%?!=#%?txt#%?0#@?set#%?410#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>31</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?411#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>32</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?426#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>36</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?427#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>38</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?423#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>39</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nome_costo_agg#%?=#%?var#%?nombre_coste_tasa_fact#@?set#%?423#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>40</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?iva_porc_vect_fact(num_iva_fact)#%?=#%?var#%?percentuale_tasse_costo_agg#$?valore_costo_agg#%?!=#%?txt#%?0#$?num_ripeticion_fact#%?>#%?txt#%?1#$?ens_coste_tasa_fact#%?!=#%?txt#%?1#@?set#%?411#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>42</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_tariffa#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>43</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?var_tmp_fact#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>44</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?iva_porc_exist_fact(var_tmp_fact)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
<riga><cmp>46</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?num_iva_fact#%?+#%?txt#%?1#%?</cmp></riga>
<riga><cmp>48</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?num_iva_fact#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>52</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?var_tmp_fact#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>60</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>61</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
<riga><cmp>65</cmp><cmp>cond2</cmp><cmp>rpt#@?or#$?valore_costo_agg#%?=#%?txt#%?0#$?valore_costo_agg#%?=#%?txt#%?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
<riga><cmp>75</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>76</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?var_tmp_fact#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>81</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?iva_porc_exist_fact(var_tmp_fact)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
<riga><cmp>83</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?num_iva_fact#%?+#%?txt#%?1#%?</cmp></riga>
<riga><cmp>84</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?num_iva_fact#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>86</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?var_tmp_fact#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>87</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>88</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
<riga><cmp>89</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?351#%?valore_costo_agg_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>90</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?oper#%?351#%?valore_costo_agg#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>91</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?342#%?=#%?var#%?nome_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>95</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
<riga><cmp>100</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
<riga><cmp>103</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?+#%?var#%?tasse_costo_agg#%?</cmp></riga>
<riga><cmp>105</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?oper#%?425#%?tot_costes_tasa_fact#%?+#%?var#%?valore_costo_agg#%?</cmp></riga>
<riga><cmp>106</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>108</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?tot_parc_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>110</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?tot_parc_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>111</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?coste_tot_fact#%?-#%?var#%?tot_no_iva_fact#%?</cmp></riga>
<riga><cmp>112</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?iva_fact#%?-#%?var#%?tot_costes_tasa_fact#%?</cmp></riga>
<riga><cmp>113</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>114</cmp><cmp>cond2</cmp><cmp>rpt#@?or#$?ens_coste_agn_fact#%?!=#%?txt#%?1#$?percentuale_tasse_costo_agg#%?!=#%?txt#%?-1#@?break#%?cont</cmp></riga>
<riga><cmp>115</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?426#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>116</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?411#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>117</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
<riga><cmp>118</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?max_num_iva_fact#%?!=#%?txt#%?1#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?set#%?427#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>119</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ultima_reserva_fact#%?=#%?var#%?numero_prenotazione#@?break#%?</cmp></riga>
<riga><cmp>120</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?339#%?=#%?var#%?numero_prenotazione#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>121</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
<riga><cmp>122</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
<riga><cmp>123</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?+#%?var#%?tasse_tariffa#%?</cmp></riga>
<riga><cmp>124</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
<riga><cmp>125</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
<riga><cmp>126</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?-#%?var#%?tasse_sconto#%?</cmp></riga>
<riga><cmp>128</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?353#%?costo_tariffa_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>129</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?352#%?sconto_senza_tasse#%?*#%?txt#%?-1#%?</cmp></riga>
<riga><cmp>130</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>131</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?tot_parc_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>132</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?tot_parc_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>133</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?coste_tot_fact#%?-#%?var#%?tot_no_iva_fact#%?</cmp></riga>
<riga><cmp>134</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?iva_fact#%?-#%?var#%?tot_costes_tasa_fact#%?</cmp></riga>
<riga><cmp>135</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>136</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?une_descuento_a_tarifa#%?=#%?txt#%?SI#@?oper#%?353#%?costo_tariffa_senza_tasse#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
<riga><cmp>137</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?une_descuento_a_tarifa#%?=#%?txt#%?SI#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>138</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?418#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>139</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?num_persone_tot#%?!=#%?txt#%?#$?num_persone_tot#%?!=#%?txt#%?0#@?set#%?418#%?=#%?txt#%? para x personas#%?txt#%?x#%?var#%?num_persone_tot</cmp></riga>
<riga><cmp>140</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?num_ripeticion_fact#%?>#%?txt#%?1#@?break#%?</cmp></riga>
<riga><cmp>141</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?347#%?coste_tot_fact#%?+#%?var#%?costo_tot#%?</cmp></riga>
<riga><cmp>142</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?348#%?coste_tot_fact#%?+#%?txt#%?0#%?</cmp></riga>
<riga><cmp>143</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?=#%?txt#%?- N.I.F. #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>144</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?.=#%?var#%?codice_fiscale_struttura#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>145</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?=#%?txt#%?Tel. #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>146</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?telefono_struttura#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>147</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?339#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>148</cmp><cmp>cond2</cmp><cmp>inr#@?#@?oper#%?412#%?num_ripeticion_fact#%?+#%?txt#%?1#%?</cmp></riga>
<riga><cmp>149</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?419#%?=#%?txt#%?SI#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>150</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?422#%?=#%?txt#%?nombre del coste a cosiderar como tasa#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>151</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?347#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>152</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?telefono_struttura#%?!=#%?txt#%?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?txt#%? - #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>153</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?sito_web_struttura#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>154</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?343#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>155</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?331#%?=#%?var#%?nome#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>156</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?332#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>157</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>158</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>159</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>160</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>161</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>162</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>163</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>164</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>165</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>166</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?405#%?=#%?var#%?partita_iva#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>167</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?406#%?=#%?var#%?codice_fiscale#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>168</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?407#%?=#%?var#%?via#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>169</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?408#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>170</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?412#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>171</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?413#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>172</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?414#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>173</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?=#%?txt#%?<img src="#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>174</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?var#%?logo_struttura#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>175</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?txt#%?" alt="Logo" style="float: right;">#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>176</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?425#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>1</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?1#%?=#%?txt#%?s#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>3</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?il#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>4</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?la#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>5</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?4#%?=#%?txt#%?Il#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>6</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?4#%?=#%?txt#%?La#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>7</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?5#%?=#%?txt#%?al#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>8</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?5#%?=#%?txt#%?alla#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>9</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?6#%?=#%?txt#%?e#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>10</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?6#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>11</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?7#%?=#%?txt#%?o#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>12</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?7#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>23</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?13#%?=#%?txt#%?el#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>24</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?13#%?=#%?txt#%?la#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>25</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?14#%?=#%?txt#%?El#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>26</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?14#%?=#%?txt#%?La#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>27</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?15#%?=#%?txt#%?al#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>28</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?15#%?=#%?txt#%?a la#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>29</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?16#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>30</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?16#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>31</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?17#%?=#%?txt#%?o#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>32</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?17#%?=#%?txt#%?a#%?txt#%?#%?txt#%?</cmp></riga>
<riga><cmp>2</cmp><cmp>compress</cmp><cmp>gz</cmp></riga>
<riga><cmp>3</cmp><cmp>compress</cmp><cmp>gz</cmp></riga>
<riga><cmp>5</cmp><cmp>allegato</cmp><cmp>0</cmp></riga>
<riga><cmp>6</cmp><cmp>allegato</cmp><cmp>0</cmp></riga>
</righetabella>
</tabella>
</database>
</backup>